@@ -31,6 +31,8 @@
 #include "systray.h"
 #include "new_window.h"
 
+static gboolean there_are_completed_on_startup = FALSE;
+ 
 /* Global Preferences */
 Preferences gwget_pref;
 
@@ -69,13 +71,6 @@ main_window(void)
 		glade_xml_signal_autoconnect(xml);
 	}
 	
-	if (!xml_new) {
-		xml_file =g_build_filename(DATADIR, "newdownload.glade", NULL);
-		xml_new = glade_xml_new(xml_file, NULL, NULL);
-		glade_xml_signal_autoconnect (xml_new);
-	}
-	
-	
 	window = glade_xml_get_widget(xml,"main_window");
 	treev = glade_xml_get_widget(xml,"treeview1");
 	model = create_model();
@@ -147,7 +142,7 @@ main_window(void)
 	
 	/* Show the toolbar ? */
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(xml,"view_toolbar")),gwget_pref.view_toolbar);
-	toolbar = glade_xml_get_widget(xml,"bonobotoolbar"); 
+	toolbar = glade_xml_get_widget(xml,"toolbar1"); 
 	menu_item=glade_xml_get_widget(GLADE_XML(xml),"view_toolbar");
 	if (gwget_pref.trayonly) {
 		gtk_widget_show(GTK_WIDGET(window));
@@ -171,14 +166,19 @@ main_window(void)
 	} else {
 		gtk_widget_hide (GTK_WIDGET(glade_xml_get_widget(xml, "statusbar")));
 	}
-		
 
-	
+	if (there_are_completed_on_startup) {
+		gtk_widget_set_sensitive (glade_xml_get_widget (xml, "clear_button"), TRUE);
+	} else {
+		gtk_widget_set_sensitive (glade_xml_get_widget (xml, "clear_button"), FALSE);
+	}
+
 	systray_load();
+	gwget_pref.docked=TRUE;
 
 	/* Create the model for the "save in" option in new download dialog */
 	save_in_model = (GtkTreeModel*)gtk_list_store_new (1, G_TYPE_STRING);
-	combo = glade_xml_get_widget (xml_new, "save_in_comboboxentry");
+	combo = glade_xml_get_widget (xml, "save_in_comboboxentry");
 	gtk_combo_box_set_model(GTK_COMBO_BOX(combo), save_in_model);
 	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY(combo), 0);
 	gtk_entry_set_text(GTK_ENTRY(GTK_BIN(combo)->child), gwget_pref.download_dir);
@@ -204,10 +204,6 @@ gboolean view_selection_func (GtkTreeSelection *selection,
 
 		gtk_tree_model_get(model, &iter, FILENAME_COLUMN, &name, -1);
 
-		if (!path_currently_selected)
-		{
-			gwget_data_set_menus (gwget_data_get_selected());
-		}
 		g_free(name);
 	}
 
@@ -330,20 +326,21 @@ gwget_get_defaults_from_gconf(void)
 				 */
 				continue;
 			} else {
+				there_are_completed_on_startup = TRUE;
 				new_download(data);
-				gwget_data_set_state(data,DL_COMPLETED);
+				gwget_data_set_state_no_sync(data,DL_COMPLETED);
 				continue;
 			}
 		}
 		    		
-		gwget_data_set_state(data,DL_NOT_RUNNING); 
+		gwget_data_set_state_no_sync(data,DL_NOT_RUNNING); 
 		if (gwget_pref.resume_at_start && data->state!=DL_COMPLETED) {
 			gwget_data_start_download(data);
 		} 
 		/* FIXME: put all the cases (error, retriving...) */
 		
 		if (state==DL_COMPLETED) {
-			gwget_data_set_state(data, state);
+			gwget_data_set_state_no_sync(data, state);
 		}
 	}
 	/*
@@ -701,24 +698,24 @@ gwget_remember_window_size_and_position(void)
 	GtkWidget *main_window;
 	GtkAllocation *allocation;
 	gint position_x,position_y;
+	GConfChangeSet *cs;
 
 	/* Remember the size of the window */
 	main_window=glade_xml_get_widget(xml,"main_window");
 	allocation= &(GTK_WIDGET (main_window)->allocation);
-	gconf_client_set_int (gconf_client, 
-			      "/apps/gwget2/default_width",
-			      allocation->width,
-			      NULL);
-	gconf_client_set_int (gconf_client, 
-			      "/apps/gwget2/default_height",
-			      allocation->height,
-			      NULL);
+	cs = gconf_change_set_new ();
+	gconf_change_set_set_int (cs, "/apps/gwget2/default_height", allocation->height);
+	gconf_change_set_set_int (cs, "/apps/gwget2/default_width", allocation->width);
 	
 	/* Remember the position */
 	gtk_window_get_position(GTK_WINDOW(main_window), &position_x, &position_y);
-	gconf_client_set_int (gconf_client,"/apps/gwget2/position_x",position_x,NULL);
-	gconf_client_set_int (gconf_client,"/apps/gwget2/position_y",position_y,NULL);
+	gconf_change_set_set_int (cs, "/apps/gwget2/position_x", position_x);
+	gconf_change_set_set_int (cs, "/apps/gwget2/position_y", position_y);
 	
+	gconf_client_commit_change_set (gconf_client, cs, TRUE, NULL);
+
+	gconf_change_set_unref (cs);
+
 	return FALSE;
 }
 
@@ -788,12 +785,11 @@ gwget_quit(void)
 	gboolean running;
 	gint response;
 	
-	gwget_remember_window_size_and_position();
 	running = gwget_remember_downloads();
 	
 	if (running) {
-		response = run_dialog(_("Cancel current downloads?"),
-				      _("There is at least one active download left. Really cancel all running transfers?"), _("Cancel"));
+		response = run_dialog(_("Stop current downloads?"),
+				      _("There is at least one active download left. Really cancel all running transfers?"), _("Exit"));
 		if (response == GTK_RESPONSE_OK) {
 			stop_all_downloads();
 			gtk_main_quit();
